Learn R Programming

biocompute (version 1.1.1)

biocompute-package: biocompute: Create and Manipulate BioCompute Objects

Description

Tools to create, validate, and export BioCompute Objects described in King et al. (2019) <doi:10.17605/osf.io/h59uh>. Users can encode information in data frames, and compose BioCompute Objects from the domains defined by the standard. A checksum validator and a JSON schema validator are provided. This package also supports exporting BioCompute Objects as JSON, PDF, HTML, or 'Word' documents, and exporting to cloud-based platforms.

Arguments

See Also

Useful links: